@@ -30,7 +30,7 @@ from jinja2htmlcompress import HTMLCompress
 
 import base64
 
-WSDL_PATH = os.path.join(config.base_path,"mm","wsdl") #this can be overridden by client settings or request parameter
+WSDL_PATH = os.path.join(config.base_path,config.support_dir,"wsdl") #this can be overridden by client settings or request parameter
 
 TOOLING_API_EXTENSIONS = ['cls', 'trigger', 'page', 'component']
 
@@ -57,7 +57,7 @@ URL_TO_ENDPOINT_TYPE = {
     PRERELEASE_ENDPOINT : "prerelease"
 }
 
-template_path = os.path.join(config.base_path,"mm","templates")
+template_path = os.path.join(config.base_path,config.support_dir,"templates")
 
 env = Environment(loader=FileSystemLoader(template_path),trim_blocks=True)
 
@@ -165,7 +165,7 @@ def decode(key, enc):
     return "".join(dec)
 
 def put_password_by_key(key, password):
-    use_keyring = config.connection.get_plugin_client_setting('mm_use_keyring', False)
+    use_keyring = config.connection.get_plugin_client_setting('mm_use_keyring', True)
     if use_keyring:
         if sys.platform == 'linux2':
             import gnomekeyring
@@ -186,7 +186,7 @@ def put_password_by_key(key, password):
         src.close()
 
 def get_password_by_key(key):
-    use_keyring = config.connection.get_plugin_client_setting('mm_use_keyring', False)
+    use_keyring = config.connection.get_plugin_client_setting('mm_use_keyring', True)
     if use_keyring:
         if sys.platform == 'linux2':
             import gnomekeyring
@@ -201,16 +201,26 @@ def get_password_by_key(key):
         else:
             return keyring.get_password('MavensMate: '+key, key)
     else: #not recommend! we only use this for CI
-        file_body = get_file_as_string(os.path.join(config.connection.get_app_settings_directory(),key+'.json'))
-        file_body_json = json.loads(file_body)
-        return decode(str(key), str(file_body_json['value']))
+        try:
+            file_body = get_file_as_string(os.path.join(config.connection.get_app_settings_directory(),key+'.json'))
+            file_body_json = json.loads(file_body)
+            return decode(str(key), str(file_body_json['value']))
+        except:
+            raise MMException('You have elected not to use keyring (mm_use_keyring = false), however, MavensMate is unable to load your local creds file.')
 
 def delete_password_by_key(key):
-    try:
-        return keyring.delete_password('MavensMate: '+key, key)
-    except:
-        #TODO: this has not been implemented in keyring yet :-(
-        pass
+    use_keyring = config.connection.get_plugin_client_setting('mm_use_keyring', True)
+    if use_keyring:
+        if sys.platform == 'linux2':
+            import gnomekeyring
+        else:
+            import keyring
+        try:
+            return keyring.delete_password('MavensMate: '+key, key)
+        except:
+            #TODO: this has not been implemented in keyring yet :-(
+            pass
+
 
 def get_file_extension(path):
     return os.path.splitext(path)[1]
@@ -375,10 +385,10 @@ def get_empty_package_xml_contents():
     return template.render(sfdc_api_version=SFDC_API_VERSION)
 
 def get_default_metadata_data():
-    return parse_json_from_file(config.base_path + "/mm/sforce/metadata/default_metadata.json")
+    return parse_json_from_file(config.base_path + "/"+config.support_dir+"/sforce/metadata/default_metadata.json")
 
 def get_child_metadata_data():
-    return parse_json_from_file(config.base_path + "/mm/sforce/metadata/default_child_metadata.json")
+    return parse_json_from_file(config.base_path + "/"+config.support_dir+"/sforce/metadata/default_child_metadata.json")
 
 def get_meta_type_by_suffix(suffix):
     try:
@@ -472,7 +482,7 @@ def put_skeleton_files_on_disk(metadata_type, where, github_template=None, param
         else:
             template_body = get_file_as_string(os.path.join(template_source,metadata_type,file_name))
     except:
-        template_body = get_file_as_string(os.path.join(config.base_path,"mm","templates","github-local",metadata_type,file_name))
+        template_body = get_file_as_string(os.path.join(config.base_path,config.support_dir,"templates","github-local",metadata_type,file_name))
 
     template = env.from_string(template_body)
     file_body = template.render(params)
@@ -515,7 +525,7 @@ def static_resource_path():
             return 'file:///'+config.base_path
 
 def generate_ui(operation,params={},args={}):
-    template_path = config.base_path + "/mm/ui/templates"
+    template_path = config.base_path + "/"+config.support_dir+"/ui/templates"
     env = Environment(loader=FileSystemLoader(template_path),trim_blocks=True)
     env.globals['uid']                      = args.uid
     env.globals['platform']                 = platform
@@ -528,6 +538,7 @@ def generate_ui(operation,params={},args={}):
     env.globals['project_location']         = config.project.location
     env.globals['static_resource_path']     = static_resource_path
     env.globals['client']                   = config.connection.plugin_client
+    env.globals['support_dir']              = config.support_dir
 
     temp = tempfile.NamedTemporaryFile(delete=False, prefix="mm", suffix=".html")
     if operation == 'new_project':
@@ -649,7 +660,7 @@ def generate_ui(operation,params={},args={}):
             else:
                 template_package = get_file_as_string(os.path.join(template_source,'package.json'))
         except:
-            template_package = get_file_as_string(os.path.join(config.base_path,"mm","templates","github-local","package.json"))
+            template_package = get_file_as_string(os.path.join(config.base_path,config.support_dir,"templates","github-local","package.json"))
 
         metadata_type = params['metadata_type']
         template_package_json = json.loads(template_package)
@@ -706,11 +717,13 @@ def calculate_coverage(result, id_to_name_map):
     return return_coverage
 
 def generate_html_response(operation, obj, params=None):
-    template_path = config.base_path + "/mm/ui/templates"
+    template_path = config.base_path + "/"+config.support_dir+"/ui/templates"
     env = Environment(loader=FileSystemLoader(template_path),trim_blocks=True,extensions=['jinja2.ext.loopcontrols', jinja2htmlcompress.HTMLCompress])
     env.globals['get_file_lines'] = get_file_lines
     env.globals['htmlize'] = htmlize
     env.globals['does_file_exist'] = does_file_exist
+    env.globals['support_dir'] = config.support_dir
+
     if operation == 'test_legacy':
         template = env.get_template('/unit_test/result.html')
         config.logger.debug(json.dumps(obj, sort_keys=True,indent=4))
@@ -846,7 +859,7 @@ def launch_ui(tmp_html_file_location):
         else:
             webbrowser.get('windows-default').open("{0}{1}".format("file:///",tmp_html_file_location))
     else:
-        os.system("open -n '"+config.base_path+"/mm/bin/MavensMateWindowServer.app' --args -url '"+tmp_html_file_location+"'")
+        os.system("open -n '"+config.base_path+"/"+config.support_dir+"/bin/MavensMateWindowServer.app' --args -url '"+tmp_html_file_location+"'")
     time.sleep(1)
     #threading.Thread(target=remove_tmp_html_file, args=(tmp_html_file_location,)).start()
 
